@@ -18,26 +18,16 @@
 { You may read GNU General Public License at:                             }
 {   http://www.gnu.org/copyleft/gpl.html                                  }
 {                                                                         }
-{ last modified: 31 Mar 2012                                              }
+{ last modified: 21 Apr 2012                                              }
 {*************************************************************************/
 
 #include "alkatraz.h"
-#include <QtCore>
 
-int rnd(int limit)
+void randomize()
 {
-    int result = qrand()/qreal(RAND_MAX)*limit;
-    if(result>=limit)
-        return limit-1;
-    else
-        return result;
-}
-
-int sgn(int val)
-{
-    if(val>0)return 1;
-    if(val==0)return 0;
-    return -1;
+    QTime c = QDateTime::currentDateTimeUtc().time();
+    int seed = c.msec()+c.second()*1000+c.minute()*1000*60+c.hour()*60*60*1000;
+    qsrand(seed);
 }
 
 void sleep(int msecs)
@@ -66,3 +56,33 @@ void* safeRealloc(void* mem, qint32 size)
         }
     }
 }
+
+#ifdef QT_GUI_LIB
+QStringList wordwrap(const QString& text, int maxWidth, const QFontMetrics &fontMetrics)
+{
+    QStringList words = text.split(" ");
+    QStringList lines;
+    QString line;
+    QString tmpLine;
+    QString wordSpaced;
+    foreach(QString word, words)
+    {
+        wordSpaced = word + " ";
+        tmpLine = line + wordSpaced;
+        if(fontMetrics.width(tmpLine) > maxWidth)
+        {
+            line.chop(1);
+            lines.append(line);
+            line = wordSpaced;
+        }
+        else
+        {
+            line = tmpLine;
+        }
+    }
+    line.chop(1);
+    if(!line.isEmpty())
+        lines.append(line);
+    return lines;
+}
+#endif
