@@ -18,13 +18,16 @@
 { You may read GNU General Public License at:                             }
 {   http://www.gnu.org/copyleft/gpl.html                                  }
 {                                                                         }
-{ last modified: 31 Mar 2012                                              }
+{ last modified: 21 Apr 2012                                              }
 {*************************************************************************/
 
 #ifndef ALKATRAZ_H
 #define ALKATRAZ_H
 
 #include <QtCore>
+#ifdef QT_GUI_LIB
+    #include <QtGui>
+#endif
 #include <stdlib.h>
 
 #ifdef Q_OS_SYMBIAN
@@ -70,9 +73,21 @@ public:
     inline void resetLastError(){lastError=err_NoError;}
 };
 
-int rnd(int limit);
-int sgn(int val);
+void randomize();
+inline int rnd(quint32 limit){return qrand()%limit;}
+
+inline int sgn(quint32 val)
+{
+    if(val>0)return 1;
+    if(val==0)return 0;
+    return -1;
+}
+
 void sleep(int msecs);
 void* safeRealloc(void* mem, qint32 size);
 
+#ifdef QT_GUI_LIB
+QStringList wordwrap(const QString& text, int maxWidth, const QFontMetrics& fontMetrics);
+#endif
+
 #endif // ALKATRAZ_H
