@@ -18,7 +18,7 @@
 { You may read GNU General Public License at:                             }
 {   http://www.gnu.org/copyleft/gpl.html                                  }
 {                                                                         }
-{ last modified: 31 Mar 2012                                              }
+{ last modified: 22 Apr 2012                                              }
 {*************************************************************************/
 
 #include "qkineticwidget.h"
@@ -167,13 +167,13 @@ void QKineticWidget::resizeEvent(QResizeEvent *event)
 
 void QKineticWidget::contextMenuEvent(QContextMenuEvent *event)
 {
+    isDown = false;
     if(activeWidget)
     {
         emit onContextMenu(activeWidget, event);
         activeWidget->setStyleSheet(cssNormal);
         activeWidget = NULL;
     }
-    isDown = false;
 }
 
 void QKineticWidget::childEvent(QChildEvent *event)
