@@ -21,7 +21,7 @@
 { You may read GNU General Public License at:                             }
 {   http://www.gnu.org/copyleft/gpl.html                                  }
 {                                                                         }
-{ last modified: 31 Mar 2012                                              }
+{ last modified: 21 Apr 2012                                              }
 {*************************************************************************/
 
 #ifndef INCLUDES_H
@@ -58,6 +58,7 @@
 #define CONTROLBUTTON_PADDING 10
 #define SKIN_INI_FILENAME "skin.ini"
 #define DEFAULT_SKIN_NAME "default"
+#define PLAYLIST_FILENAME "playlist"
 
 #define MAINWINDOW MainWindow::getInstance()
 #define OPTIONS MAINWINDOW->getOptionsWindow()->getOptions()
@@ -72,4 +73,5 @@
 class MainWindow;
 class OptionsWindow;
 
+
 #endif // INCLUDES_H
