@@ -21,7 +21,7 @@
 { You may read GNU General Public License at:                             }
 {   http://www.gnu.org/copyleft/gpl.html                                  }
 {                                                                         }
-{ last modified: 11 Apr 2012                                              }
+{ last modified: 22 Apr 2012                                              }
 {*************************************************************************/
 
 #include "mainwindow.h"
@@ -41,6 +41,11 @@ MainWindow::MainWindow(QWidget *parent) :
     timerId = 0;
     timerMinsLeft = -1;
 
+    QFont f = font();
+    f.setFamily("Arial");
+    f.setPixelSize(24);
+    notificationMetrics = new QFontMetrics(f);
+
     appDir = qApp->applicationDirPath()+"/../";
 #ifndef MAEMO5
     appDir.append(APP_NAME).append("/");
@@ -63,12 +68,28 @@ MainWindow::MainWindow(QWidget *parent) :
     cancelResumeCheck();
 
     QString lastDir = iniState->value("paths/lastdir", locMusic).toString();
+
+    if(OPTIONS.restorePlaylist)
+    {
+        QString lastFilename = iniState->value("playlist/lastfile", "").toString();
+        loadPlaylist(lastFilename);
+    }
+
     cd(lastDir);
+
+    // jump to currently selected folder or file if any,
+    // but at start, size() is messed up and so is itemsContainer's height,
+    // so call this routine with a small delay
+    QTimer::singleShot(500, this, SLOT(jumpToCurrentItem()));
 }
 
 MainWindow::~MainWindow()
 {
     iniState->setValue("paths/lastdir", fs->getCurrentDirectory());
+    iniState->setValue("playlist/lastfile", getCurrentFilename());
+
+    if(OPTIONS.restorePlaylist)
+        savePlaylist();
 
     delete optionsWindow;
     delete player;
@@ -78,6 +99,7 @@ MainWindow::~MainWindow()
 
     delete fs;
     delete skin;
+    delete notificationMetrics;
 }
 
 void MainWindow::initGUI()
@@ -123,11 +145,17 @@ void MainWindow::initGUI()
     menuBar()->addAction(tr("File types"), this, SLOT(onMenuTypesClick()));
     actionEqualizer = menuBar()->addAction("", this, SLOT(onMenuEqualizerClick()));
     actionTimer = menuBar()->addAction("", this, SLOT(onMenuTimerClick()));
+    menuBar()->addAction(tr("Shuffle playlist"), this, SLOT(onMenuShuffleClick()));
     menuBar()->addAction(tr("Options"), this, SLOT(onMenuOptionsClick()));
     menuBar()->addAction(tr("About"), this, SLOT(onMenuAboutClick()));
 
     menuFolder = new QMenu(this);
-    menuFolder->addAction(tr("Play all files in that folder"), this, SLOT(onMenuFolderAllClick()));
+    menuFolder->addAction(tr("Play all files in this folder"), this, SLOT(onMenuFolderAllClick()));
+    menuFolder->addAction(tr("Add this folder to the playlist"), this, SLOT(onMenuFolderAllAddClick()));
+
+    menuFile = new QMenu(this);
+    menuFile->addAction(tr("Play this file next"), this, SLOT(onMenuFileSetNextClick()));
+    menuFile->addAction(tr("Add this file to queue"), this, SLOT(onMenuFileAddQueueClick()));
 
     updateEqualizerActionLabel();
     updateTimerActionLabel();
@@ -262,6 +290,9 @@ void MainWindow::deinitGUI()
     delete btnNext;
     delete btnParent;
 
+    delete menuFile;
+    delete menuFolder;
+
     delete labelDir;
     itemsContainer->deleteAllChildren();
     delete itemsContainer;
@@ -392,7 +423,10 @@ void MainWindow::updateListIcons(bool playMode)
 {
     KineticListItem* item;
 
-    const QString& filename = player->getCurrentFilename();
+    //const QString& filename = player->getCurrentFilename();
+    QString filename;
+    if(currentFileIndex >= 0)
+        filename = playlist[currentFileIndex];
 
     if(currentFileItem)
     {
@@ -465,7 +499,19 @@ void MainWindow::updateListIcons(bool playMode)
 
 void MainWindow::play(const QString &filename)
 {
+    if(!OPTIONS.clearPlaylist)
+    {
+        int i = playlist.indexOf(filename);
+        if(i >= 0)
+        {
+            playIndex(i);
+            return;
+        }
+    }
     fs->getCurrentFilesFull(playlist);
+    straightPlaylist = playlist;
+    if(OPTIONS.playMode == pmo_random)
+        shuffle();
     errCount = 0;
     playIndex(playlist.indexOf(filename));
 }
@@ -486,16 +532,18 @@ void MainWindow::playIndex(int index)
     updateListIcons(true);
 }
 
-void MainWindow::playRandom()
-{
-    playIndex(rnd(playlist.size()));
-}
-
 void MainWindow::stop()
 {
     player->stop();
 }
 
+void MainWindow::shuffle()
+{
+    int n = playlist.size();
+    for(int a=0;a<n;a++)
+        playlist.swap(a, rnd(n));
+}
+
 void MainWindow::saveY()
 {
     yCache[fs->getCurrentDirectory()] = itemsContainer->getY();
@@ -567,7 +615,10 @@ void MainWindow::onItemClick(QWidget *item)
             if(currentFileItem == theItem)
                 onBtnPlayClick(); // clicked on the current file
             else
+            {
+                queue.clear();
                 play(theItem->getString()); // clicked on an other file
+            }
         }
     }
 }
@@ -576,8 +627,12 @@ void MainWindow::onContextMenuShow(QWidget *item, QContextMenuEvent *event)
 {
     KineticListItem* i = qobject_cast<KineticListItem*>(item);
     if(i)
+    {
         if(i->getBool())
             menuFolder->exec(event->globalPos());
+        else
+            menuFile->exec(event->globalPos());
+    }
 }
 
 void MainWindow::checkTimerCancel()
@@ -654,6 +709,12 @@ void MainWindow::onError()
     if(currentFileItem)
         currentFileItem->setIcon(skin->icoFileStop);
 
+    if(!queue.isEmpty())
+    {
+        runNext();
+        return;
+    }
+
     if((OPTIONS.playMode == pmo_trackOnce) || (OPTIONS.playMode == pmo_trackLoop))
     {
         // if only playing one track, then stop here
@@ -676,7 +737,7 @@ void MainWindow::onError()
         result = runPrev();
     else
         result = runNext();
-    if(result)
+    if(!result)
         showStopNotification();
 }
 
@@ -719,7 +780,42 @@ void MainWindow::onStateChanged()
 void MainWindow::onTitleChange(const QString &title)
 {
     if(OPTIONS.popupTrackTitles)
-        showNotification(title);
+    {
+        // all that nonsense below is just for fitting all the text in notification window
+        // this circumvents a weird text cropping in such windows on Maemo
+        QString cur, tot;
+        cur.setNum(currentFileIndex+1);
+        tot.setNum(playlist.size());
+        QFileInfo info(getCurrentFilename());
+        QString path = info.canonicalPath();
+        int n = path.lastIndexOf("/");
+        path.remove(0, n+1);
+        int w = width() - 50; // guessing notification popup space width, allowed for text
+        QString s = cur+"/"+tot+" - ["+path+"]";
+        QStringList dirLines = wordwrap(s, w, *notificationMetrics);
+        QStringList titleLines = wordwrap(title, w, *notificationMetrics);
+        /*
+        if(titleLines.size() > 2)
+        {
+            do{
+                titleLines.removeLast();
+            }while(titleLines.size() > 2);
+            titleLines[1].chop(5);
+            titleLines[1].append("...");
+        }
+        int maxDirLines = 3 - titleLines.size();
+        if(dirLines.size() > maxDirLines)
+        {
+            do{
+                dirLines.removeLast();
+            }while(dirLines.size() > maxDirLines);
+            dirLines[1].chop(10);
+            dirLines[1].append("...]");
+        }
+        */
+        s = dirLines.join("\n")+"\n"+titleLines.join("\n");
+        showNotification(s);
+    }
 }
 
 void MainWindow::onMenuClearClick()
@@ -731,7 +827,7 @@ void MainWindow::onMenuClearClick()
 
 void MainWindow::onMenuCurrentClick()
 {
-    const QString& filename = player->getCurrentFilename();
+    QString filename = getCurrentFilename();
     if(filename.isEmpty())
         return;
 
@@ -751,11 +847,32 @@ void MainWindow::onMenuTypesClick()
 
 void MainWindow::onMenuOptionsClick()
 {
+    bool wasRandom = (OPTIONS.playMode == pmo_random);
     if(optionsWindow->showDialog())
     {
         updateNameFilters(TypesWindow::getSupportedTypes());
         onMenuClearClick();
     }
+    if(!playlist.isEmpty())
+    {
+        bool isRandom = (OPTIONS.playMode == pmo_random);
+        if(wasRandom)
+        {
+            if(!isRandom)
+            {
+                playlist = straightPlaylist;
+                updateCurrentFileIndex();
+            }
+        }
+        else
+        {
+            if(isRandom)
+            {
+                shuffle();
+                updateCurrentFileIndex();
+            }
+        }
+    }
     updateScreenOrientation();
     cd(fs->getCurrentDirectory());
 }
@@ -789,6 +906,12 @@ void MainWindow::onMenuTimerClick()
     updateTimerActionLabel();
 }
 
+void MainWindow::onMenuShuffleClick()
+{
+    shuffle();
+    playIndex(0);
+}
+
 void MainWindow::onMenuAboutClick()
 {
     AboutWindow::showAboutDialog();
@@ -802,12 +925,57 @@ void MainWindow::onMenuFolderAllClick()
     QString curdir = fs->getCurrentDirectory();
     KineticListItem* item = (KineticListItem*)(itemsContainer->getActiveWidget());
     addFromDir(item->getString());
-    fs->cd(curdir);
-    if(OPTIONS.playMode == pmo_random)
-        playRandom();
-    else
-        playIndex(0);
     showNotification(tr("found %n file(s)", "", playlist.size()));
+    straightPlaylist = playlist;
+
+    if(OPTIONS.playMode == pmo_random)
+        shuffle();
+    fs->cd(curdir);
+    playIndex(0);
+}
+
+void MainWindow::onMenuFolderAllAddClick()
+{
+    showNotification(tr("searching..."));
+    QString curdir = fs->getCurrentDirectory();
+    KineticListItem* item = (KineticListItem*)(itemsContainer->getActiveWidget());
+    playlist = straightPlaylist;
+    int n = playlist.size();
+    addFromDir(item->getString());
+    playlist.removeDuplicates();
+    n = playlist.size() - n;
+    QString s;
+    s.setNum(playlist.size());
+    s = QString("\n")+tr("total files count")+": "+s;
+    if(n)
+        s.prepend(tr("added %n more file(s)", "", n));
+    else
+        s.prepend(tr("no new files added"));
+    showNotification(s);
+    straightPlaylist = playlist;
+
+    if(OPTIONS.playMode == pmo_random)
+        shuffle();
+    updateCurrentFileIndex();
+    fs->cd(curdir);
+}
+
+void MainWindow::onMenuFileSetNextClick()
+{
+    queue.clear();
+    KineticListItem* item = (KineticListItem*)(itemsContainer->getActiveWidget());
+    queue.append(item->getString());
+    showNotification(tr("this file will be played next"));
+}
+
+void MainWindow::onMenuFileAddQueueClick()
+{
+    KineticListItem* item = (KineticListItem*)(itemsContainer->getActiveWidget());
+    queue.append(item->getString());
+    QString s;
+    s.setNum(queue.size());
+    s.prepend(tr("files queued")+": ");
+    showNotification(tr("this file has been added to queue")+"\n"+s);
 }
 
 void MainWindow::onHeadsetStatusChange(bool isConnected)
@@ -906,6 +1074,19 @@ void MainWindow::onDirFilter(bool *pass, const QString &basename, const QString
     *pass = passDir(basename, parentDir+"/"+basename);
 }
 
+void MainWindow::jumpToCurrentItem()
+{
+    if(currentFileItem)
+    {
+        itemsContainer->centerWidgetV(currentFileItem);
+    }
+    else
+    {
+        if(currentDirItem)
+            itemsContainer->centerWidgetV(currentDirItem);
+    }
+}
+
 void MainWindow::addFromDir(const QString &dirname)
 {
     if(!fs->cd(dirname))
@@ -973,16 +1154,18 @@ bool MainWindow::runNext()
     isMovingBackwards = false;
     cancelResumeCheck();
 
+    if(!queue.isEmpty())
+    {
+        play(queue.takeFirst());
+        return true;
+    }
+
     int i;
     switch(OPTIONS.playMode)
     {
         case pmo_trackOnce:
             return false;
 
-        case pmo_random:
-            playRandom();
-            return true;
-
         case pmo_trackLoop:
             i = currentFileIndex;
             break;
@@ -994,6 +1177,7 @@ bool MainWindow::runNext()
             break;
 
         case pmo_playlistLoop:
+        case pmo_random:
             if(currentFileIndex >= (playlist.size()-1))
                 i = 0;
             else
@@ -1012,17 +1196,13 @@ bool MainWindow::runPrev()
 {
     int i;
     cancelResumeCheck();
+
     switch(OPTIONS.playMode)
     {
         case pmo_trackOnce:
             isMovingBackwards = false;
             return false;
 
-        case pmo_random:
-            isMovingBackwards = false;
-            playRandom();
-            return true;
-
         case pmo_trackLoop:
             isMovingBackwards = false;
             i = currentFileIndex;
@@ -1038,6 +1218,7 @@ bool MainWindow::runPrev()
             break;
 
         case pmo_playlistLoop:
+        case pmo_random:
             if(currentFileIndex <= 0)
                 i = playlist.size() - 1;
             else
@@ -1049,6 +1230,7 @@ bool MainWindow::runPrev()
     }
 
     isMovingBackwards = true;
+    queue.clear();
     playIndex(i);
     return true;
 }
@@ -1113,6 +1295,54 @@ void MainWindow::updateTimerActionLabel()
     actionTimer->setText(s);
 }
 
+void MainWindow::updateCurrentFileIndex()
+{
+    currentFileIndex = playlist.indexOf(player->getCurrentFilename());
+}
+
+void MainWindow::savePlaylist()
+{
+    QString filename = settingsDir+"playlist";
+    QFileEx f;
+    f.setFileName(filename);
+    if(f.open(QIODevice::WriteOnly))
+        f.writeLinesUTF8(straightPlaylist);
+    f.close();
+}
+
+void MainWindow::loadPlaylist(const QString &autoPlayFile)
+{
+    stop();
+    currentFileIndex = -1;
+    straightPlaylist.clear();
+    QString filename = settingsDir+PLAYLIST_FILENAME;
+    QFileEx f;
+    f.setFileName(filename);
+    if(f.open(QIODevice::ReadOnly))
+    {
+        straightPlaylist = f.readLinesUTF8();
+        f.close();
+    }
+    playlist = straightPlaylist;
+    if(OPTIONS.playMode == pmo_random)
+    {
+        shuffle();
+        if(!playlist.isEmpty())
+            currentFileIndex = 0;
+    }
+    else
+    {
+        currentFileIndex = playlist.indexOf(autoPlayFile);
+    }
+}
+
+QString MainWindow::getCurrentFilename() const
+{
+    if((currentFileIndex < 0) || (currentFileIndex >= playlist.size()))
+        return QString();
+    return playlist[currentFileIndex];
+}
+
 void MainWindow::showNotification(const QString &text)
 {
 #ifdef MAEMO5
@@ -1121,7 +1351,7 @@ void MainWindow::showNotification(const QString &text)
                 "/org/freedesktop/Notifications",
                 "org.freedesktop.Notifications",
                 "SystemNoteInfoprint");
-    message << text;
+    message << Qt::escape(text);
     QDBusConnection::sessionBus().call(message);
 #else
     Q_UNUSED(text);
