@@ -21,7 +21,7 @@
 { You may read GNU General Public License at:                             }
 {   http://www.gnu.org/copyleft/gpl.html                                  }
 {                                                                         }
-{ last modified: 31 Mar 2012                                              }
+{ last modified: 22 Apr 2012                                              }
 {*************************************************************************/
 
 #ifndef MAINWINDOW_H
@@ -70,8 +70,8 @@ protected:
     void updateListIcons(bool playMode = false);
     void play(const QString& filename);
     void playIndex(int index);
-    void playRandom();
     void stop();
+    void shuffle();
     void saveY();
     void restoreY();
     void openInis();
@@ -91,6 +91,10 @@ protected:
     void showStopTimerNotification();
     void stopByTimer();
     void updateTimerActionLabel();
+    void updateCurrentFileIndex();
+    void savePlaylist();
+    void loadPlaylist(const QString& autoPlayFile = QString());
+    QString getCurrentFilename() const;
 
     void resizeEvent(QResizeEvent *event);
     void timerEvent(QTimerEvent *event);
@@ -109,6 +113,7 @@ protected:
 
     QStringList nameFilters;
     QStringList playlist;
+    QStringList straightPlaylist;
     int currentFileIndex;
     QString currentFileDir;
     QHash<QString, int> yCache;
@@ -119,11 +124,12 @@ protected:
     bool checkResumeOnHangup;
     QString currentPreset;
     QString appDir;
+    QStringList queue;
 
     int timerId;
     int timerMinsLeft;
 
-    QMenu *menuFolder;
+    QMenu *menuFolder, *menuFile;
     KineticListItem* currentContextItem;
 
     PhononPlayer* player;
@@ -132,6 +138,8 @@ protected:
 
     QString locDesktop, locDocuments, locMusic, locMovies, locPictures, locHome;
 
+    QFontMetrics* notificationMetrics;
+
 protected slots:
     void onItemClick(QWidget* item);
     void onContextMenuShow(QWidget* item, QContextMenuEvent *event);
@@ -154,8 +162,12 @@ protected slots:
     void onMenuOptionsClick();
     void onMenuEqualizerClick();
     void onMenuTimerClick();
+    void onMenuShuffleClick();
     void onMenuAboutClick();
     void onMenuFolderAllClick();
+    void onMenuFolderAllAddClick();
+    void onMenuFileSetNextClick();
+    void onMenuFileAddQueueClick();
 
     void onHeadsetStatusChange(bool isConnected);
     void onCallStart();
@@ -164,6 +176,8 @@ protected slots:
     void onFileFilter(bool *pass, const QString& basename, const QString& parentDir);
     void onDirFilter(bool *pass, const QString& basename, const QString& parentDir);
 
+    void jumpToCurrentItem();
+
 signals:
     void onResize(const QSize& sz);
 
