@@ -21,7 +21,7 @@
 { You may read GNU General Public License at:                             }
 {   http://www.gnu.org/copyleft/gpl.html                                  }
 {                                                                         }
-{ last modified: 25 Mar 2012                                              }
+{ last modified: 21 Apr 2012                                              }
 {*************************************************************************/
 
 #include "optionswindow.h"
@@ -80,17 +80,19 @@ void OptionsWindow::initGui()
     screenOrientations.append(tr("Landscape", "screenOrientation"));
     screenOrientations.append(tr("Auto", "screenOrientation"));
 
+    opt_playMode = OptionItem::create(itemsContainer, oit_SelectInt, "playMode", pmo_playlistOnce, tr("Play mode"), playModes);
+    opt_screenOrientation = OptionItem::create(itemsContainer, oit_SelectInt, "screenOrientation", soo_Portrait, tr("Screen orientation"), screenOrientations);
+    opt_clearPlaylist = OptionItem::create(itemsContainer, oit_Check, "clearPlaylist", true, tr("Clear playlist when manually selecting a file"));
+    opt_restorePlaylist = OptionItem::create(itemsContainer, oit_Check, "restorePlaylist", false, tr("Restore playlist on startup"));
     opt_hideHiddenFolders = OptionItem::create(itemsContainer, oit_Check, "hideHiddenFolders", true, tr("Hide hidden folders"));
     opt_showUserFolders = OptionItem::create(itemsContainer, oit_Check, "showUserFolders", true, tr("Always show user folders"));
     opt_hideHiddenFiles = OptionItem::create(itemsContainer, oit_Check, "hideHiddenFiles", true, tr("Hide hidden files"));
     opt_useFileFilters = OptionItem::create(itemsContainer, oit_Check, "useFileFilters", true, tr("Show only files with selected extensions"));
-    opt_playMode = OptionItem::create(itemsContainer, oit_SelectInt, "playMode", pmo_playlistOnce, tr("Play mode"), playModes);
     opt_headsetUnplugAction = OptionItem::create(itemsContainer, oit_SelectInt, "headsetUnplugAction", bao_Pause, tr("Headest unplug action"), breakActions);
     opt_resumeOnPlugin = OptionItem::create(itemsContainer, oit_Check, "resumeOnPlugin", true, tr("Resume if headset has been plugged in"));
     opt_incomingCallAction = OptionItem::create(itemsContainer, oit_SelectInt, "incomingCallAction", bao_Pause, tr("Incoming call action"), breakActions);
     opt_resumeOnHangup = OptionItem::create(itemsContainer, oit_Check, "resumeOnHangup", true, tr("Resume when hang up"));
     opt_popupTrackTitles = OptionItem::create(itemsContainer, oit_Check, "popupTrackTitles", false, tr("Pop up track titles"));
-    opt_screenOrientation = OptionItem::create(itemsContainer, oit_SelectInt, "screenOrientation", soo_Portrait, tr("Screen orientation"), screenOrientations);
     opt_letTrackEnd = OptionItem::create(itemsContainer, oit_Check, "letTrackEnd", false, tr("Let a current track to end before a stop by the timer"));
     opt_buttonsCancelTimer = OptionItem::create(itemsContainer, oit_Check, "buttonsCancelTimer", false, tr("Pushing a button or a file cancels the timer"));
     opt_skinName = OptionItem::create(itemsContainer, oit_SelectString, "skinName", DEFAULT_SKIN_NAME, tr("Skin"), SKIN.getAvailableSkins());
@@ -105,6 +107,8 @@ void OptionsWindow::deinitGui()
 
 void OptionsWindow::fillOptions()
 {
+    options.clearPlaylist = opt_clearPlaylist->getBool();
+    options.restorePlaylist = opt_restorePlaylist->getBool();
     options.hideHiddenFolders = opt_hideHiddenFolders->getBool();
     options.showUserFolders = opt_showUserFolders->getBool();
     options.hideHiddenFiles = opt_hideHiddenFiles->getBool();
