@@ -21,7 +21,7 @@
 { You may read GNU General Public License at:                             }
 {   http://www.gnu.org/copyleft/gpl.html                                  }
 {                                                                         }
-{ last modified: 31 Mar 2012                                              }
+{ last modified: 21 Apr 2012                                              }
 {*************************************************************************/
 
 #ifndef OPTIONSWINDOW_H
@@ -59,6 +59,8 @@ typedef struct {
     bool hideHiddenFiles;
     bool useFileFilters;
     PlayModeOption playMode;
+    bool clearPlaylist;
+    bool restorePlaylist;
     BreakActionOption headsetUnplugAction;
     bool resumeOnPlugin;
     BreakActionOption incomingCallAction;
@@ -86,11 +88,12 @@ protected:
     void fillOptions();
     void updateSkin();
     void reposition(const QSize& sz, int rows=1);
-
     QList<OptionItem*> items;
     bool isChanged;
 
     OptionItem
+        *opt_clearPlaylist,
+        *opt_restorePlaylist,
         *opt_hideHiddenFolders,
         *opt_showUserFolders,
         *opt_hideHiddenFiles,
