@@ -9,108 +9,108 @@
         <translation>Версия</translation>
     </message>
     <message>
-        <location filename="../src/aboutwindow.cpp" line="39"/>
+        <location filename="../src/aboutwindow.cpp" line="38"/>
         <source>Project site</source>
         <translation>Сайт проекта</translation>
     </message>
     <message>
-        <location filename="../src/aboutwindow.cpp" line="40"/>
+        <location filename="../src/aboutwindow.cpp" line="39"/>
         <source>Developer</source>
         <translation>Разработчик</translation>
     </message>
     <message>
-        <location filename="../src/aboutwindow.cpp" line="41"/>
+        <location filename="../src/aboutwindow.cpp" line="40"/>
         <source>Contact email</source>
         <translation>Контактный email</translation>
     </message>
     <message>
-        <location filename="../src/aboutwindow.cpp" line="42"/>
+        <location filename="../src/aboutwindow.cpp" line="41"/>
         <source>Contact name</source>
         <translation>Контактное лицо</translation>
     </message>
     <message>
-        <location filename="../src/aboutwindow.cpp" line="43"/>
+        <location filename="../src/aboutwindow.cpp" line="42"/>
         <source>Developer&apos;s site</source>
         <translation>Сайт разработчика</translation>
     </message>
     <message>
-        <location filename="../src/aboutwindow.cpp" line="46"/>
+        <location filename="../src/aboutwindow.cpp" line="45"/>
         <source>Compressed modules support</source>
         <translation>Поддержка сжатых модулей</translation>
     </message>
     <message>
-        <location filename="../src/aboutwindow.cpp" line="48"/>
+        <location filename="../src/aboutwindow.cpp" line="47"/>
         <source>NO (install &apos;unzip&apos; package for this to work)</source>
         <translation>НЕТ (установите пакет &apos;unzip&apos;, для воспроизведения сжатой модульной музыки)</translation>
     </message>
     <message>
-        <location filename="../src/aboutwindow.cpp" line="54"/>
+        <location filename="../src/aboutwindow.cpp" line="53"/>
         <source>NO (install &apos;%1&apos; gstreamer plugin to enable equalizer)</source>
         <translation>НЕТ (установите плагин для gstreamer &apos;%1&apos; чтобы добавить поддержку эквалайзера)</translation>
     </message>
     <message>
-        <location filename="../src/aboutwindow.cpp" line="50"/>
-        <location filename="../src/aboutwindow.cpp" line="60"/>
+        <location filename="../src/aboutwindow.cpp" line="49"/>
+        <location filename="../src/aboutwindow.cpp" line="59"/>
         <source>YES</source>
         <translation>ДА</translation>
     </message>
     <message>
-        <location filename="../src/aboutwindow.cpp" line="51"/>
+        <location filename="../src/aboutwindow.cpp" line="50"/>
         <source>Equalizer support</source>
         <translation>Поддержка эквалайзера</translation>
     </message>
     <message>
-        <location filename="../src/aboutwindow.cpp" line="63"/>
+        <location filename="../src/aboutwindow.cpp" line="62"/>
         <source>To make more MIME types available, install appropriate gstreamer plugins</source>
         <translation>Устанавливайте соответствующие плагины для gstreamer, чтобы добавить поддержку новых форматов</translation>
     </message>
     <message>
-        <location filename="../src/aboutwindow.cpp" line="62"/>
+        <location filename="../src/aboutwindow.cpp" line="61"/>
         <source>Supported MIME types</source>
         <translation>Поддерживаемые MIME типы</translation>
     </message>
     <message>
-        <location filename="../src/aboutwindow.cpp" line="65"/>
+        <location filename="../src/aboutwindow.cpp" line="64"/>
         <source>Current skin</source>
         <translation>Текущий скин</translation>
     </message>
     <message>
-        <location filename="../src/aboutwindow.cpp" line="44"/>
+        <location filename="../src/aboutwindow.cpp" line="43"/>
         <source>This project was inspired by %1.</source>
         <translation>Данный проект был вдохновлён %1.</translation>
     </message>
     <message>
-        <location filename="../src/aboutwindow.cpp" line="73"/>
+        <location filename="../src/aboutwindow.cpp" line="72"/>
         <source>The README file for the current skin is either empty or not found.</source>
         <translation>Файл README текущего скина не найден либо пуст.</translation>
     </message>
     <message>
-        <location filename="../src/aboutwindow.cpp" line="77"/>
+        <location filename="../src/aboutwindow.cpp" line="76"/>
         <source>The following is a contents of README file for a current skin:</source>
         <translation>Ниже приведено содержимое README файла текущего скина:</translation>
     </message>
     <message>
-        <location filename="../src/aboutwindow.cpp" line="140"/>
+        <location filename="../src/aboutwindow.cpp" line="139"/>
         <source>About</source>
         <translation>О программе</translation>
     </message>
     <message>
-        <location filename="../src/aboutwindow.cpp" line="150"/>
+        <location filename="../src/aboutwindow.cpp" line="149"/>
         <source>App</source>
         <translation>Приложение</translation>
     </message>
     <message>
-        <location filename="../src/aboutwindow.cpp" line="151"/>
+        <location filename="../src/aboutwindow.cpp" line="150"/>
         <source>System</source>
         <translation>Система</translation>
     </message>
     <message>
-        <location filename="../src/aboutwindow.cpp" line="152"/>
+        <location filename="../src/aboutwindow.cpp" line="151"/>
         <source>Skin</source>
         <translation>Скин</translation>
     </message>
     <message>
-        <location filename="../src/aboutwindow.cpp" line="153"/>
+        <location filename="../src/aboutwindow.cpp" line="152"/>
         <source>License</source>
         <translation>Лицензия</translation>
     </message>
@@ -259,88 +259,143 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../src/mainwindow.cpp" line="121"/>
+        <location filename="../src/mainwindow.cpp" line="143"/>
         <source>Clear cache</source>
         <translation>Очистить кэш</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="122"/>
+        <location filename="../src/mainwindow.cpp" line="144"/>
         <source>Jump to a current file</source>
         <translation>К текущему файлу</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="123"/>
+        <location filename="../src/mainwindow.cpp" line="145"/>
         <source>File types</source>
         <translation>Типы файлов</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="127"/>
+        <location filename="../src/mainwindow.cpp" line="148"/>
+        <source>Shuffle playlist</source>
+        <translation>Перемешать</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="150"/>
         <source>About</source>
         <translation>О программе</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="725"/>
+        <location filename="../src/mainwindow.cpp" line="153"/>
+        <source>Play all files in this folder</source>
+        <translation>Воспроизвести всё в этой папке</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="154"/>
+        <source>Add this folder to the playlist</source>
+        <translation>Добавить эту папку в плэйлист</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="157"/>
+        <source>Play this file next</source>
+        <translation>Играть этот файл следующим</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="158"/>
+        <source>Add this file to queue</source>
+        <translation>Добавить этот файл в очередь</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="824"/>
         <source>Cache has been cleared</source>
         <translation>Кэш очищен</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="764"/>
+        <location filename="../src/mainwindow.cpp" line="884"/>
         <source>Equalizer module not found!</source>
         <translation>Модуль эквалайзера не найден!</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="781"/>
+        <location filename="../src/mainwindow.cpp" line="901"/>
         <source>The timer has been started</source>
         <translation>Таймер запущен</translation>
     </message>
+    <message numerus="yes">
+        <location filename="../src/mainwindow.cpp" line="951"/>
+        <source>added %n more file(s)</source>
+        <translation>
+            <numerusform>добавлен ещё %n файл</numerusform>
+            <numerusform>добавлено ещё %n файла</numerusform>
+            <numerusform>добавлено ещё %n файлов</numerusform>
+        </translation>
+    </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="962"/>
+        <location filename="../src/mainwindow.cpp" line="949"/>
+        <source>total files count</source>
+        <translation>общее число файлов</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="953"/>
+        <source>no new files added</source>
+        <translation>новых файлов не добавлено</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="968"/>
+        <source>this file will be played next</source>
+        <translation>этот файл будет проигран следующим</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="977"/>
+        <source>files queued</source>
+        <translation>файлов в очереди</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="978"/>
+        <source>this file has been added to queue</source>
+        <translation>этот файл был добавлен в очередь</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="1146"/>
         <source>off</source>
         <comment>eqActionLabel</comment>
         <translation>выкл.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="965"/>
+        <location filename="../src/mainwindow.cpp" line="1149"/>
         <source>Equalizer</source>
         <translation>Эквалайзер</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1055"/>
+        <location filename="../src/mainwindow.cpp" line="1240"/>
         <source>Playback has been stopped</source>
         <translation>Воспроизведение остановлено</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1081"/>
+        <location filename="../src/mainwindow.cpp" line="1266"/>
         <source>Timer has been stopped</source>
         <translation>Таймер остановлен</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1093"/>
+        <location filename="../src/mainwindow.cpp" line="1278"/>
         <source>Timer</source>
         <translation>Таймер</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1097"/>
+        <location filename="../src/mainwindow.cpp" line="1282"/>
         <source>off</source>
         <translation>выкл.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="126"/>
+        <location filename="../src/mainwindow.cpp" line="149"/>
         <source>Options</source>
         <translation>Настройки</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="130"/>
-        <source>Play all files in that folder</source>
-        <translation>Воспроизвести всё в этой папке</translation>
-    </message>
-    <message>
-        <location filename="../src/mainwindow.cpp" line="796"/>
+        <location filename="../src/mainwindow.cpp" line="922"/>
+        <location filename="../src/mainwindow.cpp" line="939"/>
         <source>searching...</source>
         <translation>ищем...</translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/mainwindow.cpp" line="807"/>
+        <location filename="../src/mainwindow.cpp" line="928"/>
         <source>found %n file(s)</source>
         <translation>
             <numerusform>нашёлся %n файл</numerusform>
@@ -423,72 +478,82 @@
         <translation>Автоматически</translation>
     </message>
     <message>
-        <location filename="../src/optionswindow.cpp" line="83"/>
+        <location filename="../src/optionswindow.cpp" line="85"/>
+        <source>Clear playlist when manually selecting a file</source>
+        <translation>Очищать плэйлист при выборе файла вручную</translation>
+    </message>
+    <message>
+        <location filename="../src/optionswindow.cpp" line="86"/>
+        <source>Restore playlist on startup</source>
+        <translation>Восстанавливать плэйлист при запуске</translation>
+    </message>
+    <message>
+        <location filename="../src/optionswindow.cpp" line="87"/>
         <source>Hide hidden folders</source>
         <translation>Прятать скрытые папки</translation>
     </message>
     <message>
-        <location filename="../src/optionswindow.cpp" line="84"/>
+        <location filename="../src/optionswindow.cpp" line="88"/>
         <source>Always show user folders</source>
         <translation>Всегда показывать папки пользователя</translation>
     </message>
     <message>
-        <location filename="../src/optionswindow.cpp" line="85"/>
+        <location filename="../src/optionswindow.cpp" line="89"/>
         <source>Hide hidden files</source>
         <translation>Прятать скрытые файлы</translation>
     </message>
     <message>
-        <location filename="../src/optionswindow.cpp" line="86"/>
+        <location filename="../src/optionswindow.cpp" line="90"/>
         <source>Show only files with selected extensions</source>
         <translation>Показывать только файлы с выбранными расширениями</translation>
     </message>
     <message>
-        <location filename="../src/optionswindow.cpp" line="94"/>
+        <location filename="../src/optionswindow.cpp" line="96"/>
         <source>Let a current track to end before a stop by the timer</source>
         <translation>Закончить текущий трек перед остановкой по таймеру</translation>
     </message>
     <message>
-        <location filename="../src/optionswindow.cpp" line="95"/>
+        <location filename="../src/optionswindow.cpp" line="97"/>
         <source>Pushing a button or a file cancels the timer</source>
         <translation>Нажатие на кнопки или на файлы отменяет таймер</translation>
     </message>
     <message>
-        <location filename="../src/optionswindow.cpp" line="96"/>
+        <location filename="../src/optionswindow.cpp" line="98"/>
         <source>Skin</source>
         <translation>Скин</translation>
     </message>
     <message>
-        <location filename="../src/optionswindow.cpp" line="87"/>
+        <location filename="../src/optionswindow.cpp" line="83"/>
         <source>Play mode</source>
         <translation>Режим воспроизведения</translation>
     </message>
     <message>
-        <location filename="../src/optionswindow.cpp" line="88"/>
+        <location filename="../src/optionswindow.cpp" line="91"/>
         <source>Headest unplug action</source>
         <translation>Действие при отключении наушников</translation>
     </message>
     <message>
-        <location filename="../src/optionswindow.cpp" line="89"/>
+        <location filename="../src/optionswindow.cpp" line="92"/>
         <source>Resume if headset has been plugged in</source>
         <translation>Возобновить, если наушники были подключены</translation>
     </message>
     <message>
-        <location filename="../src/optionswindow.cpp" line="90"/>
+        <location filename="../src/optionswindow.cpp" line="93"/>
         <source>Incoming call action</source>
         <translation>Действие при входящем вызове</translation>
     </message>
     <message>
-        <location filename="../src/optionswindow.cpp" line="91"/>
+        <location filename="../src/optionswindow.cpp" line="94"/>
         <source>Resume when hang up</source>
         <translation>Возобновить при окончании вызова</translation>
     </message>
     <message>
-        <location filename="../src/optionswindow.cpp" line="92"/>
+        <location filename="../src/optionswindow.cpp" line="95"/>
         <source>Pop up track titles</source>
         <translation>Всплывающие названия треков</translation>
     </message>
     <message>
-        <location filename="../src/optionswindow.cpp" line="93"/>
+        <location filename="../src/optionswindow.cpp" line="84"/>
         <source>Screen orientation</source>
         <translation>Ориентация экрана</translation>
     </message>
